==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeProcessingInstruction.h <==
// class gnu.xml.libxmlj.dom.GnomeProcessingInstruction

// class file dependencies
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class bf53844df15b4511 gnu_xml_libxmlj_dom_GnomeProcessingInstruction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$getTarget$12ef98d215594559(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);
extern void _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$setData$659a7707842e4261(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$getTarget$12ef98d215594559;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$setData$659a7707842e4261;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);
	struct _jc_java_lang_String$object	*(*getTarget$12ef98d215594559)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);
	void	(*setData$659a7707842e4261)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object {
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeProcessingInstruction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeProcessingInstruction.h <==
// class gnu.xml.libxmlj.dom.GnomeProcessingInstruction

// class file dependencies
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class bf53844df15b4511 gnu_xml_libxmlj_dom_GnomeProcessingInstruction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$getTarget$12ef98d215594559(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$setData$659a7707842e4261(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$getTarget$12ef98d215594559;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$setData$659a7707842e4261;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTarget$12ef98d215594559)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;
	void	(*setData$659a7707842e4261)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vmethods	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_refs	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeProcessingInstruction;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$object {
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$vtype _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeProcessingInstruction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeProcessingInstruction$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeProcessingInstruction_H_ */
